==> deepin-screen-recorder-5.11.11-1.src.tar.gz: deepin-screen-recorder-5.11.11/translations/deepin-screen-recorder_bg.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="bg" version="2.1">
<context>
    <name>CountdownTooltip</name>
    <message>
        <location filename="../src/countdown_tooltip.cpp" line="78"/>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/main_window.cpp" line="76"/>
        <source>Deepin screen recorder</source>
        <translation>Deepin запис на екрана</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="136"/>
        <source>Start recording</source>
        <translation>Започни запис</translation>
    </message>
    <message>
        <location filename="../src/main_window.cpp" line="454"/>
        <source>Select area</source>
        <translation>Избор на област</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <location filename="../src/record_process.cpp" line="229"/>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <location filename="../src/record_process.cpp" line="291"/>
        <source>View</source>
        <translation>Изглед</translation>
    </message>
    <message>
        <location filename="../src/record_process.cpp" line="301"/>
        <source>Recording finished</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/record_process.cpp" line="302"/>
        <source>Saved to</source>
        <translation>Запазено в</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <location filename="../src/start_tooltip.cpp" line="48"/>
        <source>Click or drag to
select the area to record</source>
        <translation>Щракни или влачи до
избраната област за запис</translation>
    </message>
</context>
</TS>

==> deepin-screen-recorder-5.12.15-1.src.tar.gz: deepin-screen-recorder-5.12.15/translations/deepin-screen-recorder_bg.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bg">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Щракнете на системната икона
или краткият път отново за спиране на записа</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Recording</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>View</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>select-area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ignore</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Изглед</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Записа приключи</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Record</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Quick start</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rectangle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ellipse</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pencil</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Undo</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Increase height up</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Increase height down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Increase width left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Increase width right</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Help</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keystroke</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Започни запис</translation>
    </message>
    <message>
        <source>Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tools</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start OCR</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screen Capture</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Screenshot</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Blur</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mosaic</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Sound On</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Microphone</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System Audio</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sound Off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show Keystroke</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide Keystroke</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam On</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Webcam Off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show Click</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Format:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>GIF</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>MP4</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>FPS:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>5 fps</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>10 fps</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>20 fps</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>24 fps</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>30 fps</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rectangle</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ellipse</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Line</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Arrow</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pencil</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save to</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Format</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PNG</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>JPG</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>BMP</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>MKV</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show pointer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show Pointer</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Extract Text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>webm</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>ogg</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
